@@ -43,7 +43,7 @@ def build_resolver(parser):
 
 def build_api(parser):
     api_group = parser.add_argument_group('APIs endpoints')
-    api_group.add_argument('--warehouse', help='warehouse API URL.')
+    api_group.add_argument('--warehouse', nargs='*', help='warehouse API URL.')
     api_group.add_argument('--bitbucket', help='bitbucket API URL.')
     api_group.add_argument('--repo', choices=REPOSITORIES, help='force repository for first-level deps.')
 
